@@ -1037,7 +1037,8 @@ pub mod os {
         target_os = "redox",
         target_os = "solaris",
         target_os = "illumos",
-        target_os = "haiku"
+        target_os = "haiku",
+        target_os = "hurd"
     ))]
     pub mod unix {
         use std::ffi::{OsStr, OsString};
@@ -1070,6 +1071,14 @@ pub mod os {
             /// Can be used to construct tests users, which by default come with a
             /// dummy password field.
             fn with_password<S: AsRef<OsStr> + ?Sized>(self, password: &S) -> Self;
+
+            /// Returns the user's GECOS comment
+            fn gecos(&self) -> &OsStr;
+
+            /// Sets this user's GECOS comment to the given string.
+            /// Can be used to construct tests users, which by default come with a
+            /// dummy GECOS field.
+            fn with_gecos<S: AsRef<OsStr> + ?Sized>(self, gecos: &S) -> Self;
         }
 
         /// Unix-specific extensions for `Group`s.
@@ -1093,6 +1102,9 @@ pub mod os {
 
             /// The user’s encrypted password.
             pub password: OsString,
+
+            /// The user's GECOS comment
+            pub gecos: OsString,
         }
 
         impl Default for UserExtras {
@@ -1101,6 +1113,7 @@ pub mod os {
                     home_dir: "/var/empty".into(),
                     shell: "/bin/false".into(),
                     password: "*".into(),
+                    gecos: "".into(),
                 }
             }
         }
@@ -1118,11 +1131,13 @@ pub mod os {
                     let home_dir = from_raw_buf::<OsString>(passwd.pw_dir).into();
                     let shell = from_raw_buf::<OsString>(passwd.pw_shell).into();
                     let password = from_raw_buf::<OsString>(passwd.pw_passwd);
+                    let gecos = from_raw_buf::<OsString>(passwd.pw_gecos);
 
                     Self {
                         home_dir,
                         shell,
                         password,
+                        gecos,
                     }
                 }
             }
@@ -1134,7 +1149,8 @@ pub mod os {
             target_os = "redox",
             target_os = "solaris",
             target_os = "illumos",
-            target_os = "haiku"
+            target_os = "haiku",
+            target_os = "hurd"
         ))]
         use super::super::User;
 
@@ -1144,7 +1160,8 @@ pub mod os {
             target_os = "redox",
             target_os = "solaris",
             target_os = "illumos",
-            target_os = "haiku"
+            target_os = "haiku",
+            target_os = "hurd"
         ))]
         impl UserExt for User {
             fn home_dir(&self) -> &Path {
@@ -1173,6 +1190,15 @@ pub mod os {
                 self.extras.password = password.into();
                 self
             }
+
+            fn gecos(&self) -> &OsStr {
+                &self.extras.gecos
+            }
+
+            fn with_gecos<S: AsRef<OsStr> + ?Sized>(mut self, gecos: &S) -> Self {
+                self.extras.gecos = gecos.into();
+                self
+            }
         }
 
         /// Unix-specific fields for `Group`s.
@@ -1274,6 +1300,15 @@ pub mod os {
                 self.extras.extras.password = password.into();
                 self
             }
+
+            fn gecos(&self) -> &OsStr {
+                &self.extras.extras.gecos
+            }
+
+            fn with_gecos<S: AsRef<OsStr> + ?Sized>(mut self, gecos: &S) -> Self {
+                self.extras.extras.gecos = gecos.into();
+                self
+            }
         }
 
         /// BSD-specific accessors for `User`s.
@@ -1323,7 +1358,8 @@ pub mod os {
         target_os = "redox",
         target_os = "solaris",
         target_os = "illumos",
-        target_os = "haiku"
+        target_os = "haiku",
+        target_os = "hurd"
     ))]
     pub type UserExtras = unix::UserExtras;
 
@@ -1339,7 +1375,8 @@ pub mod os {
         target_os = "redox",
         target_os = "solaris",
         target_os = "illumos",
-        target_os = "haiku"
+        target_os = "haiku",
+        target_os = "hurd"
     ))]
     pub type GroupExtras = unix::GroupExtras;
 }
@@ -1386,10 +1423,11 @@ mod test {
         // Not a real test but can be used to verify correct results
         // Use with --nocapture on test executable to show output
         println!(
-            "HOME={:?}, SHELL={:?}, PASSWD={:?}",
+            "HOME={:?}, SHELL={:?}, PASSWD={:?}, GECOS={:?}",
             user.home_dir(),
             user.shell(),
-            user.password()
+            user.password(),
+            user.gecos()
         );
     }
 
@@ -1433,3 +1471,65 @@ mod test {
         assert!(group.is_none());
     }
 }
+
+#[cfg(all(test, feature = "test-integration"))]
+mod mocked_test {
+    extern crate serial_test;
+
+    use self::serial_test::serial;
+
+    use super::{os::unix::GroupExt, *};
+
+    #[test]
+    #[serial]
+    fn mocked_username() {
+        let user = get_user_by_uid(1337).unwrap();
+
+        assert_eq!(user.name(), "fred");
+    }
+
+    #[test]
+    #[serial]
+    fn mocked_uid_for_uid() {
+        let user = get_user_by_uid(1337).unwrap();
+
+        assert_eq!(user.uid, 1337);
+    }
+
+    #[test]
+    #[serial]
+    fn mocked_user_by_name() {
+        let user_by_name = get_user_by_name("fred");
+
+        assert!(user_by_name.is_some());
+        assert_eq!(user_by_name.unwrap().name(), "fred");
+
+        // User names containing '\0' cannot be used (for now)
+        let user = get_user_by_name("user\0");
+        assert!(user.is_none());
+    }
+
+    #[test]
+    #[serial]
+    fn mocked_group_by_name() {
+        let group_by_name = get_group_by_name("bosses");
+
+        assert!(group_by_name.is_some());
+        assert_eq!(group_by_name.unwrap().name(), "bosses");
+
+        // Group names containing '\0' cannot be used (for now)
+        let group = get_group_by_name("users\0");
+        assert!(group.is_none());
+    }
+
+    #[test]
+    #[serial]
+    fn mocked_group_members() {
+        let group = get_group_by_gid(43).unwrap();
+        let members = group.members();
+
+        assert_eq!(members.len(), 2);
+        assert!(members.contains(&"bob".into()));
+        assert!(members.contains(&"martha".into()));
+    }
+}
